referrerpolicy=no-referrer-when-downgrade

check_double_voting_proof

Function check_double_voting_proof 

pub fn check_double_voting_proof<Number, Id>(
    report: &DoubleVotingProof<Number, Id, <Id as RuntimeAppPublic>::Signature>,
) -> bool
where Id: BeefyAuthorityId + PartialEq, Number: Clone + Encode + PartialEq,
Verifies the equivocation proof by making sure that both votes target different blocks and that its signatures are valid.